pygeodesy.fmath.Fhypot

Package pygeodesy :: Module fmath :: Class Fhypot |
[frames] | no frames]

# Class Fhypot

      object --+
               |
    named._Named --+
                   |
          fsums.Fsum --+
                       |
                      Fhypot

Precision summation and hypotenuse, default `root=2`.

Instance Methods
__init__(self, *xs, **root_name_f2product_nonfinites_RESIDUAL_raiser) New Fhypot hypotenuse of (the root of) several components (raised to the power root). |
Inherited from `fsums.Fsum`: `Fsum2Tuple_`, `Fsum_`, `Fsumf_`, `RESIDUAL`, `__abs__`, `__add__`, `__bool__`, `__call__`, `__ceil__`, `__cmp__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floor__`, `__floordiv__`, `__ge__`, `__gt__`, `__hash__`, `__iadd__`, `__idiv__`, `__ifloordiv__`, `__imatmul__`, `__imod__`, `__imul__`, `__int__`, `__invert__`, `__ipow__`, `__isub__`, `__iter__`, `__itruediv__`, `__le__`, `__len__`, `__long__`, `__lt__`, `__matmul__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmatmul__`, `__rmod__`, `__rmul__`, `__round__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__str__`, `__sub__`, `__truediv__`, `__trunc__`, `as_integer_ratio`, `cmp`, `copy`, `divmod`, `f2mul`, `f2mul_`, `f2product`, `fadd`, `fadd_`, `fcopy`, `fdiv`, `fdivmod`, `fint`, `fint2`, `fma`, `fma_`, `fmul`, `fover`, `fpow`, `fset_`, `fsub`, `fsub_`, `fsum`, `fsum2`, `fsum2_`, `fsum2f_`, `fsum_`, `fsumf_`, `int_float`, `is_exact`, `is_finite`, `is_integer`, `is_math_fma`, `is_math_fsum`, `is_scalar`, `nonfinites`, `pow`, `rdiv`, `root`, `signOf`, `toRepr`, `toStr` Inherited from `named._Named`: `__format__`, `__repr__`, `attrs`, `classof`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `fsums.Fsum`: `as_iscalar`, `ceil`, `float_int`, `floor`, `imag`, `nonfinitesOK`, `partials`, `real`, `residual` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, *xs, **root_name_f2product_nonfinites_RESIDUAL_raiser) (Constructor) |
New Fhypot hypotenuse of (the root of) several components (raised to the power root). Arguments: `xs` - Components (each `scalar`, an Fsum or Fsum2Tuple), all positional. `root_name_f2product_nonfinites_RESIDUAL_raiser` - Optional, exponent and `root=2` order (`scalar`), `name=NN` (`str`), `raiser=True` (`bool`) for raising ResidualErrors and other settings, see class Fsum and method root. Overrides: object.__init__